==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicatorDescription, _super);
    function AbsoluteVolumeOscillatorIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.ec = 0;
        _this.eb = 0;
        return _this;
    }
    AbsoluteVolumeOscillatorIndicatorDescription.prototype.get_type = function () {
        return "AbsoluteVolumeOscillatorIndicator";
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicatorDescription.prototype, "shortPeriod", {
        get: function () {
            return this.ec;
        },
        set: function (a) {
            this.ec = a;
            this.e("ShortPeriod");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicatorDescription.prototype, "longPeriod", {
        get: function () {
            return this.eb;
        },
        set: function (a) {
            this.eb = a;
            this.e("LongPeriod");
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicatorDescription.$t = markType(AbsoluteVolumeOscillatorIndicatorDescription, 'AbsoluteVolumeOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return AbsoluteVolumeOscillatorIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { AbsoluteVolumeOscillatorIndicatorDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicatorDescription, _super);
    function AbsoluteVolumeOscillatorIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.go = 0;
        _this.gn = 0;
        return _this;
    }
    AbsoluteVolumeOscillatorIndicatorDescription.prototype.get_type = function () {
        return "AbsoluteVolumeOscillatorIndicator";
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicatorDescription.prototype, "shortPeriod", {
        get: function () {
            return this.go;
        },
        set: function (a) {
            this.go = a;
            this.g("ShortPeriod");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicatorDescription.prototype, "longPeriod", {
        get: function () {
            return this.gn;
        },
        set: function (a) {
            this.gn = a;
            this.g("LongPeriod");
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicatorDescription.$t = markType(AbsoluteVolumeOscillatorIndicatorDescription, 'AbsoluteVolumeOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return AbsoluteVolumeOscillatorIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { AbsoluteVolumeOscillatorIndicatorDescription };
